@@ -336,7 +336,9 @@ class Shade(_Base):
             self.geometry.check_planar(tolerance, raise_exception=True)
         except ValueError as e:
             msg = 'Shade "{}" is not planar.\n{}'.format(self.full_id, e)
-            return self._validation_message(msg, raise_exception, detailed, '000101')
+            return self._validation_message(
+                msg, raise_exception, detailed, '000101',
+                error_type='Non-Planar Geometry')
         return [] if detailed else ''
 
     def check_self_intersecting(self, tolerance=0.01, raise_exception=True,
@@ -363,7 +365,9 @@ class Shade(_Base):
                     return [] if detailed else ''  # valid with removed dup vertex
             except AssertionError:
                 pass  # zero area face; treat it as self-intersecting
-            return self._validation_message(msg, raise_exception, detailed, '000102')
+            return self._validation_message(
+                msg, raise_exception, detailed, '000102',
+                error_type='Self-Intersecting Geometry')
         return [] if detailed else ''
 
     def check_non_zero(self, tolerance=0.0001, raise_exception=True, detailed=False):
@@ -384,7 +388,9 @@ class Shade(_Base):
         if self.area < tolerance:
             msg = 'Shade "{}" geometry is too small. Area must be at least {}. ' \
                 'Got {}.'.format(self.full_id, tolerance, self.area)
-            return self._validation_message(msg, raise_exception, detailed, '000103')
+            return self._validation_message(
+                msg, raise_exception, detailed, '000103',
+                error_type='Zero-Area Geometry')
         return [] if detailed else ''
 
     @property
